Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(382)

Unified Diff: components/security_interstitials/core/safe_browsing_quiet_error_ui.h

Issue 2854263003: Add quiet safe browsing interstitial for WebView (Closed)
Patch Set: Fix tests Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/security_interstitials/core/safe_browsing_quiet_error_ui.h
diff --git a/components/security_interstitials/core/safe_browsing_loud_error_ui.h b/components/security_interstitials/core/safe_browsing_quiet_error_ui.h
similarity index 55%
copy from components/security_interstitials/core/safe_browsing_loud_error_ui.h
copy to components/security_interstitials/core/safe_browsing_quiet_error_ui.h
index c90391aee52a26c164088a211614cf7e26667834..5c9d1d1d4c8188f28cb542faf8636da60ffe4323 100644
--- a/components/security_interstitials/core/safe_browsing_loud_error_ui.h
+++ b/components/security_interstitials/core/safe_browsing_quiet_error_ui.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef COMPONENTS_SECURITY_INTERSTITIALS_CORE_SAFE_BROWSING_LOUD_ERROR_UI_H_
-#define COMPONENTS_SECURITY_INTERSTITIALS_CORE_SAFE_BROWSING_LOUD_ERROR_UI_H_
+#ifndef COMPONENTS_SECURITY_INTERSTITIALS_CORE_SAFE_BROWSING_QUIET_ERROR_UI_H_
+#define COMPONENTS_SECURITY_INTERSTITIALS_CORE_SAFE_BROWSING_QUIET_ERROR_UI_H_
#include "base/macros.h"
#include "base/time/time.h"
@@ -14,41 +14,41 @@
namespace security_interstitials {
-// Loud version of the safe browsing interstitial. This is the full screen
-// version of the interstitial used on Desktop, Android and iOS. It is
-// selectively used in parts of WebView.
-// This class displays UI for Safe Browsing errors that block page loads. This
-// class is purely about visual display; it does not do any error-handling logic
-// to determine what type of error should be displayed when.
-class SafeBrowsingLoudErrorUI
+// Quiet version of the safe browsing interstitial. This is the small screen
+// version of the interstitial selectively used in parts of WebView.
+// This class displays a quiet UI for Safe Browsing errors that block page loads
+// specifically for WebView. This class is purely about visual display; it does
+// not do any error-handling logic to determine what type of error should be
+// displayed when.
+class SafeBrowsingQuietErrorUI
: public security_interstitials::BaseSafeBrowsingErrorUI {
public:
- SafeBrowsingLoudErrorUI(
+ SafeBrowsingQuietErrorUI(
const GURL& request_url,
const GURL& main_frame_url,
BaseSafeBrowsingErrorUI::SBInterstitialReason reason,
const BaseSafeBrowsingErrorUI::SBErrorDisplayOptions& display_options,
const std::string& app_locale,
const base::Time& time_triggered,
- ControllerClient* controller);
+ ControllerClient* controller,
+ const bool is_giant_webview);
+ ~SafeBrowsingQuietErrorUI() override;
- ~SafeBrowsingLoudErrorUI() override;
+ void PopulateStringsForHtml(base::DictionaryValue* load_time_data) override;
- // Implement BaseSafeBrowsingErrorUI.
- void PopulateStringsForHTML(base::DictionaryValue* load_time_data) override;
void HandleCommand(SecurityInterstitialCommands command) override;
private:
// Fills the passed dictionary with the values to be passed to the template
// when creating the HTML.
- void PopulateExtendedReportingOption(base::DictionaryValue* load_time_data);
void PopulateMalwareLoadTimeData(base::DictionaryValue* load_time_data);
- void PopulateHarmfulLoadTimeData(base::DictionaryValue* load_time_data);
void PopulatePhishingLoadTimeData(base::DictionaryValue* load_time_data);
- DISALLOW_COPY_AND_ASSIGN(SafeBrowsingLoudErrorUI);
+ bool is_giant_webview_;
+
+ DISALLOW_COPY_AND_ASSIGN(SafeBrowsingQuietErrorUI);
};
} // security_interstitials
-#endif // COMPONENTS_SECURITY_INTERSTITIALS_CORE_SAFE_BROWSING_LOUD_ERROR_UI_H_
+#endif // COMPONENTS_SECURITY_INTERSTITIALS_CORE_SAFE_BROWSING_QUIET_ERROR_UI_H_

Powered by Google App Engine
This is Rietveld 408576698